@@ -10,6 +10,7 @@ import traceback
 import hashlib
 import lzma
 
+
 try:
     import bflb_path
 except ImportError:
@@ -48,6 +49,7 @@ if conf_sign:
     chip_xtal = cgc.choice_xtal
     chip_brd = cgc.choice_board
     bl_factory_params_file_prefix = cgc.show_text_first_value
+    boot2bin = "chipsp_boot2.bin"  
 else:
     chip_dict = {
         "bl56x": "bl60x",
@@ -60,6 +62,7 @@ else:
     chip_xtal = 'bl60x_xtal'
     chip_brd = 'bl60x_brd'
     bl_factory_params_file_prefix = 'bl_factory_params_'
+    boot2bin = "blsp_boot2.bin"
 
 
 def parse_rfpa(bin):
@@ -151,7 +154,7 @@ class BflbIotTool(object):
         eflash_loader_cfg_org = os.path.join(chip_path, chipname, "eflash_loader/eflash_loader_cfg.conf")
         self.eflash_loader_cfg = os.path.join(chip_path, chipname, "eflash_loader/eflash_loader_cfg.ini")
         if os.path.isfile(self.eflash_loader_cfg) is False:
-            shutil.copy(eflash_loader_cfg_org, self.eflash_loader_cfg)
+            shutil.copyfile(eflash_loader_cfg_org, self.eflash_loader_cfg)
         if chiptype == "bl60x":
             bh_cfg_file_org = os.path.join(chip_path, chipname,
                                            "efuse_bootheader/efuse_bootheader_cfg_dp.conf")
@@ -160,7 +163,7 @@ class BflbIotTool(object):
                                            "efuse_bootheader/efuse_bootheader_cfg.conf")
         self.bh_cfg_file = os.path.join(chip_path, chipname, "efuse_bootheader/efuse_bootheader_cfg.ini")
         if os.path.isfile(self.bh_cfg_file) is False:
-            shutil.copy(bh_cfg_file_org, self.bh_cfg_file)
+            shutil.copyfile(bh_cfg_file_org, self.bh_cfg_file)
         
 #         ini_file_kw = 'efuse_bootheader_cfg_'
 #         ini_file_kw_len = len(ini_file_kw)
@@ -299,7 +302,7 @@ class BflbIotTool(object):
                 f_org = os.path.join(chip_path, chipname, "img_create_iot", "img_create_cfg.conf")
             f = os.path.join(chip_path, chipname, "img_create_iot", "img_create_cfg.ini")
             if os.path.isfile(f) is False:
-                shutil.copy(f_org, f)
+                shutil.copyfile(f_org, f)
         else:
             f = cfg_ini
         cfg.read(f)
@@ -865,7 +868,7 @@ class BflbIotTool(object):
                 f_org = os.path.join(chip_path, chipname, "img_create_iot", "img_create_cfg_boot2.conf")
                 f = os.path.join(chip_path, chipname, "img_create_iot", "img_create_cfg_boot2.ini")
                 if os.path.isfile(f) is False:
-                    shutil.copy(f_org, f)
+                    shutil.copyfile(f_org, f)
                 self.bl60x_image_gen(chipname, chiptype, cpu_type, "boot2", boot2,
                                 config["param"]['aes_key'], config["param"]['aes_iv'], 
                                 config["input_path"]["publickey"], config["input_path"]["privatekey"], 
@@ -902,7 +905,7 @@ class BflbIotTool(object):
             media_bin = config['input_path']['meida_bin_input']
             if media_bin is not None and len(media_bin) > 0:
                 try:
-                    shutil.copy(media_bin, os.path.join(chip_path, chipname, "img_create_iot", "media.bin"))
+                    shutil.copyfile(media_bin, os.path.join(chip_path, chipname, "img_create_iot", "media.bin"))
                 except Exception as e:
                     bflb_utils.printf(e)
             media_bin_d = True
@@ -939,7 +942,7 @@ class BflbIotTool(object):
                 f_org = os.path.join(chip_path, chipname, "img_create_iot", "img_create_cfg_mfg.conf")
                 f = os.path.join(chip_path, chipname, "img_create_iot", "img_create_cfg_mfg.ini")
                 if os.path.isfile(f) is False:
-                    shutil.copy(f_org, f)
+                    shutil.copyfile(f_org, f)
                 self.bl60x_image_gen(chipname, chiptype, cpu_type, "mfg", mfg, 
                                 config["param"]['aes_key'], config["param"]['aes_iv'], 
                                 config["input_path"]["publickey"], config["input_path"]["privatekey"],
@@ -1099,7 +1102,7 @@ def iot_download_cmd(args):
     config["param"]["comport_uart"] =  args.port
     config["param"]["speed_uart"] = str(args.baudrate)
     config["param"]["speed_jlink"] = str(args.baudrate)
-    config["param"]["bl60x_xtal"] = args.xtal
+    config["param"][chip_xtal] = args.xtal
     config["param"]["aes_key"] = ""
     config["param"]["aes_iv"] = ""
     config["check_box"]["partition_download"] = True
@@ -1127,37 +1130,37 @@ def iot_download_cmd(args):
         config["check_box"]["boot2_download"] = False
         config["input_path"]["boot2_bin_input"] = ""
         if not args.xtal: 
-            config["param"]["bl60x_xtal"] = "32M"
+            config["param"][chip_xtal] = "32M"
         else:   
-            config["param"]["bl60x_xtal"] = args.xtal 
+            config["param"][chip_xtal] = args.xtal 
         if not args.dts: 
-            config["input_path"]["dts_input"] = os.path.join(chip_path, chipname, "device_tree/bl_factory_params_IoTKitA_32M.dts")
+            config["input_path"]["dts_input"] = os.path.join(chip_path, chipname, "device_tree", bl_factory_params_file_prefix+"IoTKitA_32M.dts")
         else:   
             config["input_path"]["dts_input"] = args.dts
     elif chiptype == "bl602":
         config["check_box"]["boot2_download"] = True
-        config["input_path"]["boot2_bin_input"] = os.path.join(chip_path, chipname, "builtin_imgs", "blsp_boot2.bin")
+        config["input_path"]["boot2_bin_input"] = os.path.join(chip_path, chipname, "builtin_imgs", boot2bin)
         if not args.xtal: 
-            config["param"]["bl60x_xtal"] = "40M"
+            config["param"][chip_xtal] = "40M"
         else:   
-            config["param"]["bl60x_xtal"] = args.xtal 
+            config["param"][chip_xtal] = args.xtal 
         if not args.dts: 
-            config["input_path"]["dts_input"] = os.path.join(chip_path, chipname, "device_tree/bl_factory_params_IoTKitA_40M.dts")
+            config["input_path"]["dts_input"] = os.path.join(chip_path, chipname, "device_tree", bl_factory_params_file_prefix+"IoTKitA_40M.dts")
         else:   
             config["input_path"]["dts_input"] = args.dts
     elif chiptype == "bl60x":
         config["check_box"]["boot2_download"] = True
-        config["input_path"]["boot2_bin_input"] = os.path.join(chip_path, chipname, "builtin_imgs", "blsp_boot2.bin")
+        config["input_path"]["boot2_bin_input"] = os.path.join(chip_path, chipname, "builtin_imgs", boot2bin)
         if not args.xtal: 
-            config["param"]["bl60x_xtal"] = "38.4M"
+            config["param"][chip_xtal] = "38.4M"
         else:   
-            config["param"]["bl60x_xtal"] = args.xtal 
+            config["param"][chip_xtal] = args.xtal 
         if not args.dts: 
-            config["input_path"]["dts_input"] = os.path.join(chip_path, chipname, "device_tree/bl_factory_params_avb_38.4M.dts")
+            config["input_path"]["dts_input"] = os.path.join(chip_path, chipname, "device_tree", bl_factory_params_file_prefix+"avb_38.4M.dts")
         else:   
             config["input_path"]["dts_input"] = args.dts
     else:
-        bflb_utils.printf("Chip type is not in bl60x/bl602/bl702")
+        bflb_utils.printf("Chip type is not correct")
         return
     
     if config["param"]["interface_type"].lower() == "jlink" and args.baudrate > 12000:
@@ -1173,10 +1176,10 @@ def iot_download_cmd(args):
     if act == "build":
         f_org = os.path.join(chip_path, args.chipname, "img_create_iot", "whole_flash_data.bin")
         f = "firmware.bin"
-        shutil.copy(f_org, f)
+        shutil.copyfile(f_org, f)
     
     
-def run():
+def run():    
     port = None
     ports = []
     for item in get_serial_ports():
@@ -1187,7 +1190,7 @@ def run():
         except Exception:
             port = sorted(ports)[0]
     firmware_default = os.path.join(app_path, "img", "project.bin")
-    parser = argparse.ArgumentParser(description='bflb iot tool')
+    parser = argparse.ArgumentParser(description='iot-tool')
     parser.add_argument('--chipname', required=True, help='chip name')
     parser.add_argument("--interface", dest="interface", default="uart", help="interface to use") 
     parser.add_argument("--port", dest="port", default=port, help="serial port to use")
